@@ -20,4 +20,14 @@ and by receiving updates from it.
 // Panel contains state and logic to protect the main state from getting flooded
 // with low-level wayland and gtk sizing events.
 
-pub mod popover;
\ No newline at end of file
+pub mod external;
+pub mod popover;
+
+/// The implementing actor is able to receive and handle messages.
+/// Typically, it's the sending end of the channel,
+/// whose other end is inside an event loop.
+// TODO: implement for remaning actors and make the event loop refer to this.
+pub trait Destination {
+    type Event;
+    fn send(&self, event: Self::Event);
+}
