@@ -23,10 +23,9 @@ mod assert_matches;
 mod logging;
 
 mod action;
-mod actors;
+pub mod actors;
 mod animation;
 pub mod data;
-mod debug;
 mod drawing;
 mod event_loop;
 pub mod float_ord;
@@ -39,7 +38,7 @@ mod outputs;
 mod panel;
 mod popover;
 mod receiver;
-mod resources;
+pub mod resources;
 mod state;
 mod style;
 mod submission;
