@@ -17,9 +17,9 @@
  */
 #ifndef SERVER_CONTEXT_SERVICE_H
 #define SERVER_CONTEXT_SERVICE_H 1
+#include <gtk/gtk.h>
 
-#include "src/layout.h"
-#include "src/submission.h"
+#include "main.h"
 
 G_BEGIN_DECLS
 
@@ -28,8 +28,8 @@ G_BEGIN_DECLS
 /** Manages the lifecycle of the window displaying layouts. */
 G_DECLARE_FINAL_TYPE (ServerContextService, server_context_service, SERVER, CONTEXT_SERVICE, GObject)
 
-ServerContextService *server_context_service_new(EekboardContextService *self, struct submission *submission, struct squeek_layout_state *layout, struct squeek_state_manager *state_manager);
-enum squeek_arrangement_kind server_context_service_get_layout_type(ServerContextService *);
+ServerContextService *server_context_service_new(struct squeek_state_manager *state_manager);
 G_END_DECLS
+
 #endif  /* SERVER_CONTEXT_SERVICE_H */
 
